@@ -1,4 +1,4 @@
-from ... import Server
+from ... import Server, Event
 
 
 class SocketConfig:
@@ -14,3 +14,7 @@ class SocketConfig:
         self.max_reconnect_timeout = max_reconnect_timeout
         self.initial_reconnect_timeout = initial_reconnect_timeout
         self.connection_kwargs = kwargs
+
+
+class SocketConnectionResetEvent(Event):
+    pass
